/********************************************************************************
** Form generated from reading UI file 'mainwindow.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MAINWINDOW_H
#define UI_MAINWINDOW_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_MainWindow
{
public:
    QGridLayout *gridLayout;
    QFrame *warningFrame;
    QHBoxLayout *horizontalLayout;
    QLabel *warningIconLabel;
    QLabel *label;
    QPushButton *infoButton;
    QPushButton *hideButton;
    QTabWidget *tabWidget;
    QLabel *versionLabel;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *MainWindow)
    {
        if (MainWindow->objectName().isEmpty())
            MainWindow->setObjectName("MainWindow");
        MainWindow->resize(735, 549);
        gridLayout = new QGridLayout(MainWindow);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(6, 6, 6, 6);
        warningFrame = new QFrame(MainWindow);
        warningFrame->setObjectName("warningFrame");
        warningFrame->setFrameShape(QFrame::StyledPanel);
        warningFrame->setFrameShadow(QFrame::Raised);
        horizontalLayout = new QHBoxLayout(warningFrame);
        horizontalLayout->setObjectName("horizontalLayout");
        warningIconLabel = new QLabel(warningFrame);
        warningIconLabel->setObjectName("warningIconLabel");
        warningIconLabel->setText(QString::fromUtf8("..."));

        horizontalLayout->addWidget(warningIconLabel);

        label = new QLabel(warningFrame);
        label->setObjectName("label");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(label);

        infoButton = new QPushButton(warningFrame);
        infoButton->setObjectName("infoButton");

        horizontalLayout->addWidget(infoButton);

        hideButton = new QPushButton(warningFrame);
        hideButton->setObjectName("hideButton");

        horizontalLayout->addWidget(hideButton);


        gridLayout->addWidget(warningFrame, 0, 0, 1, 2);

        tabWidget = new QTabWidget(MainWindow);
        tabWidget->setObjectName("tabWidget");
        tabWidget->setFocusPolicy(Qt::StrongFocus);

        gridLayout->addWidget(tabWidget, 1, 0, 1, 2);

        versionLabel = new QLabel(MainWindow);
        versionLabel->setObjectName("versionLabel");
        versionLabel->setText(QString::fromUtf8("..."));

        gridLayout->addWidget(versionLabel, 2, 0, 1, 1);

        buttonBox = new QDialogButtonBox(MainWindow);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 2, 1, 1, 1);


        retranslateUi(MainWindow);
        QObject::connect(hideButton, &QPushButton::clicked, warningFrame, qOverload<>(&QFrame::hide));

        QMetaObject::connectSlotsByName(MainWindow);
    } // setupUi

    void retranslateUi(QWidget *MainWindow)
    {
        MainWindow->setWindowTitle(QCoreApplication::translate("MainWindow", "Qt6 Configuration Tool", nullptr));
        label->setText(QCoreApplication::translate("MainWindow", "The application is not configured correctly.", nullptr));
        infoButton->setText(QCoreApplication::translate("MainWindow", "Information", nullptr));
        hideButton->setText(QCoreApplication::translate("MainWindow", "Hide", nullptr));
    } // retranslateUi

};

namespace Ui {
    class MainWindow: public Ui_MainWindow {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MAINWINDOW_H
