/********************************************************************************
** Form generated from reading UI file 'appearancepage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_APPEARANCEPAGE_H
#define UI_APPEARANCEPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QMdiArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_AppearancePage
{
public:
    QGridLayout *gridLayout_2;
    QFormLayout *formLayout;
    QLabel *label;
    QComboBox *styleComboBox;
    QLabel *colorScheeLabel;
    QHBoxLayout *horizontalLayout;
    QComboBox *colorSchemeComboBox;
    QToolButton *colorSchemeButton;
    QLabel *dialogLabel;
    QComboBox *dialogComboBox;
    QSpacerItem *horizontalSpacer;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QComboBox *paletteComboBox;
    QSpacerItem *horizontalSpacer_2;
    QMdiArea *mdiArea;

    void setupUi(QWidget *AppearancePage)
    {
        if (AppearancePage->objectName().isEmpty())
            AppearancePage->setObjectName("AppearancePage");
        AppearancePage->resize(596, 470);
        AppearancePage->setWindowTitle(QString::fromUtf8("Form"));
        gridLayout_2 = new QGridLayout(AppearancePage);
        gridLayout_2->setObjectName("gridLayout_2");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        label = new QLabel(AppearancePage);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        styleComboBox = new QComboBox(AppearancePage);
        styleComboBox->setObjectName("styleComboBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(styleComboBox->sizePolicy().hasHeightForWidth());
        styleComboBox->setSizePolicy(sizePolicy);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, styleComboBox);

        colorScheeLabel = new QLabel(AppearancePage);
        colorScheeLabel->setObjectName("colorScheeLabel");
        colorScheeLabel->setEnabled(true);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, colorScheeLabel);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        colorSchemeComboBox = new QComboBox(AppearancePage);
        colorSchemeComboBox->setObjectName("colorSchemeComboBox");
        colorSchemeComboBox->setEnabled(true);
        colorSchemeComboBox->setMinimumSize(QSize(150, 0));
        colorSchemeComboBox->setFocusPolicy(Qt::TabFocus);

        horizontalLayout->addWidget(colorSchemeComboBox);

        colorSchemeButton = new QToolButton(AppearancePage);
        colorSchemeButton->setObjectName("colorSchemeButton");
        colorSchemeButton->setText(QString::fromUtf8("..."));
        colorSchemeButton->setPopupMode(QToolButton::InstantPopup);
        colorSchemeButton->setArrowType(Qt::NoArrow);

        horizontalLayout->addWidget(colorSchemeButton);


        formLayout->setLayout(1, QFormLayout::ItemRole::FieldRole, horizontalLayout);

        dialogLabel = new QLabel(AppearancePage);
        dialogLabel->setObjectName("dialogLabel");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, dialogLabel);

        dialogComboBox = new QComboBox(AppearancePage);
        dialogComboBox->setObjectName("dialogComboBox");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, dialogComboBox);


        gridLayout_2->addLayout(formLayout, 0, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(253, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer, 0, 1, 1, 1);

        groupBox = new QGroupBox(AppearancePage);
        groupBox->setObjectName("groupBox");
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        paletteComboBox = new QComboBox(groupBox);
        paletteComboBox->addItem(QString());
        paletteComboBox->addItem(QString());
        paletteComboBox->addItem(QString());
        paletteComboBox->setObjectName("paletteComboBox");
        paletteComboBox->setFocusPolicy(Qt::TabFocus);

        gridLayout->addWidget(paletteComboBox, 0, 0, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(82, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 0, 1, 1, 1);

        mdiArea = new QMdiArea(groupBox);
        mdiArea->setObjectName("mdiArea");
        mdiArea->setActivationOrder(QMdiArea::ActivationHistoryOrder);
        mdiArea->setTabsMovable(false);

        gridLayout->addWidget(mdiArea, 1, 0, 1, 2);


        gridLayout_2->addWidget(groupBox, 1, 0, 1, 2);


        retranslateUi(AppearancePage);

        QMetaObject::connectSlotsByName(AppearancePage);
    } // setupUi

    void retranslateUi(QWidget *AppearancePage)
    {
        label->setText(QCoreApplication::translate("AppearancePage", "Style:", nullptr));
        colorScheeLabel->setText(QCoreApplication::translate("AppearancePage", "Color scheme:", nullptr));
        dialogLabel->setText(QCoreApplication::translate("AppearancePage", "Standard dialogs:", nullptr));
        groupBox->setTitle(QCoreApplication::translate("AppearancePage", "Preview", nullptr));
        paletteComboBox->setItemText(0, QCoreApplication::translate("AppearancePage", "Active palette", nullptr));
        paletteComboBox->setItemText(1, QCoreApplication::translate("AppearancePage", "Inactive palette", nullptr));
        paletteComboBox->setItemText(2, QCoreApplication::translate("AppearancePage", "Disabled palette", nullptr));

        (void)AppearancePage;
    } // retranslateUi

};

namespace Ui {
    class AppearancePage: public Ui_AppearancePage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_APPEARANCEPAGE_H
