/********************************************************************************
** Form generated from reading UI file 'fontconfigdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FONTCONFIGDIALOG_H
#define UI_FONTCONFIGDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpinBox>

QT_BEGIN_NAMESPACE

class Ui_FontConfigDialog
{
public:
    QGridLayout *gridLayout;
    QCheckBox *disableBoldAutohintCheckBox;
    QLabel *label_3;
    QCheckBox *autohinterCheckBox;
    QCheckBox *hintingCheckBox;
    QDialogButtonBox *buttonBox;
    QLabel *label_4;
    QComboBox *lcdFilterComboBox;
    QComboBox *rgbaComboBox;
    QComboBox *hintingStyleComboBox;
    QLabel *label_2;
    QCheckBox *antialisingCheckBox;
    QLabel *label;
    QSpinBox *dpiSpinBox;

    void setupUi(QDialog *FontConfigDialog)
    {
        if (FontConfigDialog->objectName().isEmpty())
            FontConfigDialog->setObjectName("FontConfigDialog");
        FontConfigDialog->resize(349, 295);
        gridLayout = new QGridLayout(FontConfigDialog);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(6, -1, 6, 6);
        disableBoldAutohintCheckBox = new QCheckBox(FontConfigDialog);
        disableBoldAutohintCheckBox->setObjectName("disableBoldAutohintCheckBox");

        gridLayout->addWidget(disableBoldAutohintCheckBox, 5, 0, 1, 2);

        label_3 = new QLabel(FontConfigDialog);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 6, 0, 1, 1);

        autohinterCheckBox = new QCheckBox(FontConfigDialog);
        autohinterCheckBox->setObjectName("autohinterCheckBox");

        gridLayout->addWidget(autohinterCheckBox, 4, 0, 1, 2);

        hintingCheckBox = new QCheckBox(FontConfigDialog);
        hintingCheckBox->setObjectName("hintingCheckBox");

        gridLayout->addWidget(hintingCheckBox, 1, 0, 1, 2);

        buttonBox = new QDialogButtonBox(FontConfigDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 8, 0, 1, 2);

        label_4 = new QLabel(FontConfigDialog);
        label_4->setObjectName("label_4");

        gridLayout->addWidget(label_4, 7, 0, 1, 1);

        lcdFilterComboBox = new QComboBox(FontConfigDialog);
        lcdFilterComboBox->setObjectName("lcdFilterComboBox");

        gridLayout->addWidget(lcdFilterComboBox, 6, 1, 1, 1);

        rgbaComboBox = new QComboBox(FontConfigDialog);
        rgbaComboBox->setObjectName("rgbaComboBox");

        gridLayout->addWidget(rgbaComboBox, 3, 1, 1, 1);

        hintingStyleComboBox = new QComboBox(FontConfigDialog);
        hintingStyleComboBox->setObjectName("hintingStyleComboBox");

        gridLayout->addWidget(hintingStyleComboBox, 2, 1, 1, 1);

        label_2 = new QLabel(FontConfigDialog);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 3, 0, 1, 1);

        antialisingCheckBox = new QCheckBox(FontConfigDialog);
        antialisingCheckBox->setObjectName("antialisingCheckBox");

        gridLayout->addWidget(antialisingCheckBox, 0, 0, 1, 2);

        label = new QLabel(FontConfigDialog);
        label->setObjectName("label");

        gridLayout->addWidget(label, 2, 0, 1, 1);

        dpiSpinBox = new QSpinBox(FontConfigDialog);
        dpiSpinBox->setObjectName("dpiSpinBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(dpiSpinBox->sizePolicy().hasHeightForWidth());
        dpiSpinBox->setSizePolicy(sizePolicy);
        dpiSpinBox->setMinimum(80);
        dpiSpinBox->setMaximum(180);
        dpiSpinBox->setValue(102);

        gridLayout->addWidget(dpiSpinBox, 7, 1, 1, 1);

        QWidget::setTabOrder(antialisingCheckBox, hintingCheckBox);
        QWidget::setTabOrder(hintingCheckBox, hintingStyleComboBox);
        QWidget::setTabOrder(hintingStyleComboBox, rgbaComboBox);
        QWidget::setTabOrder(rgbaComboBox, autohinterCheckBox);
        QWidget::setTabOrder(autohinterCheckBox, disableBoldAutohintCheckBox);
        QWidget::setTabOrder(disableBoldAutohintCheckBox, lcdFilterComboBox);
        QWidget::setTabOrder(lcdFilterComboBox, dpiSpinBox);
        QWidget::setTabOrder(dpiSpinBox, buttonBox);

        retranslateUi(FontConfigDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, FontConfigDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, FontConfigDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(FontConfigDialog);
    } // setupUi

    void retranslateUi(QDialog *FontConfigDialog)
    {
        FontConfigDialog->setWindowTitle(QCoreApplication::translate("FontConfigDialog", "Font Configuration", nullptr));
        disableBoldAutohintCheckBox->setText(QCoreApplication::translate("FontConfigDialog", "Disable automatic hinting for bold fonts", nullptr));
        label_3->setText(QCoreApplication::translate("FontConfigDialog", "LCD filter:", nullptr));
        autohinterCheckBox->setText(QCoreApplication::translate("FontConfigDialog", "Automatic hinting", nullptr));
        hintingCheckBox->setText(QCoreApplication::translate("FontConfigDialog", "Hinting", nullptr));
        label_4->setText(QCoreApplication::translate("FontConfigDialog", "Font resolution:", nullptr));
        label_2->setText(QCoreApplication::translate("FontConfigDialog", "Subpixel geometry:", nullptr));
        antialisingCheckBox->setText(QCoreApplication::translate("FontConfigDialog", "Antialiasing", nullptr));
        label->setText(QCoreApplication::translate("FontConfigDialog", "Hinting style:", nullptr));
        dpiSpinBox->setSuffix(QCoreApplication::translate("FontConfigDialog", " dpi", nullptr));
    } // retranslateUi

};

namespace Ui {
    class FontConfigDialog: public Ui_FontConfigDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_FONTCONFIGDIALOG_H
