/********************************************************************************
** Form generated from reading UI file 'qsseditordialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QSSEDITORDIALOG_H
#define UI_QSSEDITORDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_QSSEditorDialog
{
public:
    QVBoxLayout *verticalLayout;
    QTextEdit *textEdit;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *QSSEditorDialog)
    {
        if (QSSEditorDialog->objectName().isEmpty())
            QSSEditorDialog->setObjectName("QSSEditorDialog");
        QSSEditorDialog->resize(643, 499);
        verticalLayout = new QVBoxLayout(QSSEditorDialog);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(6, -1, 6, 6);
        textEdit = new QTextEdit(QSSEditorDialog);
        textEdit->setObjectName("textEdit");
        textEdit->setAcceptRichText(false);

        verticalLayout->addWidget(textEdit);

        buttonBox = new QDialogButtonBox(QSSEditorDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Save);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(QSSEditorDialog);

        QMetaObject::connectSlotsByName(QSSEditorDialog);
    } // setupUi

    void retranslateUi(QDialog *QSSEditorDialog)
    {
        QSSEditorDialog->setWindowTitle(QCoreApplication::translate("QSSEditorDialog", "Style Sheet Editor", nullptr));
    } // retranslateUi

};

namespace Ui {
    class QSSEditorDialog: public Ui_QSSEditorDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_QSSEDITORDIALOG_H
