/********************************************************************************
** Form generated from reading UI file 'qsspage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QSSPAGE_H
#define UI_QSSPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_QSSPage
{
public:
    QGridLayout *gridLayout;
    QPushButton *createButton;
    QPushButton *removeButton;
    QSpacerItem *horizontalSpacer;
    QListWidget *qssListWidget;
    QPushButton *editButton;
    QPushButton *renameButton;

    void setupUi(QWidget *QSSPage)
    {
        if (QSSPage->objectName().isEmpty())
            QSSPage->setObjectName("QSSPage");
        QSSPage->resize(483, 320);
        QSSPage->setWindowTitle(QString::fromUtf8("Style Sheet Editor"));
        gridLayout = new QGridLayout(QSSPage);
        gridLayout->setObjectName("gridLayout");
        createButton = new QPushButton(QSSPage);
        createButton->setObjectName("createButton");
        createButton->setEnabled(true);

        gridLayout->addWidget(createButton, 1, 0, 1, 1);

        removeButton = new QPushButton(QSSPage);
        removeButton->setObjectName("removeButton");
        removeButton->setEnabled(false);

        gridLayout->addWidget(removeButton, 1, 3, 1, 1);

        horizontalSpacer = new QSpacerItem(189, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 1, 5, 1, 1);

        qssListWidget = new QListWidget(QSSPage);
        qssListWidget->setObjectName("qssListWidget");
        qssListWidget->setContextMenuPolicy(Qt::CustomContextMenu);
        qssListWidget->setAlternatingRowColors(true);

        gridLayout->addWidget(qssListWidget, 0, 0, 1, 6);

        editButton = new QPushButton(QSSPage);
        editButton->setObjectName("editButton");
        editButton->setEnabled(false);

        gridLayout->addWidget(editButton, 1, 1, 1, 1);

        renameButton = new QPushButton(QSSPage);
        renameButton->setObjectName("renameButton");
        renameButton->setEnabled(false);

        gridLayout->addWidget(renameButton, 1, 2, 1, 1);

        QWidget::setTabOrder(qssListWidget, createButton);
        QWidget::setTabOrder(createButton, editButton);
        QWidget::setTabOrder(editButton, renameButton);
        QWidget::setTabOrder(renameButton, removeButton);

        retranslateUi(QSSPage);

        QMetaObject::connectSlotsByName(QSSPage);
    } // setupUi

    void retranslateUi(QWidget *QSSPage)
    {
        createButton->setText(QCoreApplication::translate("QSSPage", "Create", nullptr));
        removeButton->setText(QCoreApplication::translate("QSSPage", "Remove", nullptr));
        editButton->setText(QCoreApplication::translate("QSSPage", "Edit", nullptr));
        renameButton->setText(QCoreApplication::translate("QSSPage", "Rename", nullptr));
        (void)QSSPage;
    } // retranslateUi

};

namespace Ui {
    class QSSPage: public Ui_QSSPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_QSSPAGE_H
