/********************************************************************************
** Form generated from reading UI file 'troubleshootingpage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TROUBLESHOOTINGPAGE_H
#define UI_TROUBLESHOOTINGPAGE_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_TroubleshootingPage
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QGridLayout *gridLayout;
    QPushButton *addAppButton;
    QPushButton *removeAppButton;
    QSpacerItem *verticalSpacer;
    QListWidget *ignoredAppsListWidget;
    QCheckBox *forceRasterCheckBox;

    void setupUi(QWidget *TroubleshootingPage)
    {
        if (TroubleshootingPage->objectName().isEmpty())
            TroubleshootingPage->setObjectName("TroubleshootingPage");
        TroubleshootingPage->resize(485, 371);
        TroubleshootingPage->setWindowTitle(QString::fromUtf8("Form"));
        verticalLayout = new QVBoxLayout(TroubleshootingPage);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(TroubleshootingPage);
        label->setObjectName("label");

        verticalLayout->addWidget(label);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        addAppButton = new QPushButton(TroubleshootingPage);
        addAppButton->setObjectName("addAppButton");
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("list-add");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        addAppButton->setIcon(icon);

        gridLayout->addWidget(addAppButton, 0, 1, 1, 1);

        removeAppButton = new QPushButton(TroubleshootingPage);
        removeAppButton->setObjectName("removeAppButton");
        QIcon icon1;
        iconThemeName = QString::fromUtf8("list-remove");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        removeAppButton->setIcon(icon1);

        gridLayout->addWidget(removeAppButton, 1, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 68, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 2, 1, 1, 1);

        ignoredAppsListWidget = new QListWidget(TroubleshootingPage);
        ignoredAppsListWidget->setObjectName("ignoredAppsListWidget");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ignoredAppsListWidget->sizePolicy().hasHeightForWidth());
        ignoredAppsListWidget->setSizePolicy(sizePolicy);

        gridLayout->addWidget(ignoredAppsListWidget, 0, 0, 3, 1);


        verticalLayout->addLayout(gridLayout);

        forceRasterCheckBox = new QCheckBox(TroubleshootingPage);
        forceRasterCheckBox->setObjectName("forceRasterCheckBox");
        forceRasterCheckBox->setTristate(true);

        verticalLayout->addWidget(forceRasterCheckBox);


        retranslateUi(TroubleshootingPage);

        QMetaObject::connectSlotsByName(TroubleshootingPage);
    } // setupUi

    void retranslateUi(QWidget *TroubleshootingPage)
    {
        label->setText(QCoreApplication::translate("TroubleshootingPage", "Ignored applications:", nullptr));
        addAppButton->setText(QCoreApplication::translate("TroubleshootingPage", "Add...", nullptr));
        removeAppButton->setText(QCoreApplication::translate("TroubleshootingPage", "Remove", nullptr));
#if QT_CONFIG(tooltip)
        ignoredAppsListWidget->setToolTip(QCoreApplication::translate("TroubleshootingPage", "Do not apply any styles and color schemes for the listed applications.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        forceRasterCheckBox->setToolTip(QCoreApplication::translate("TroubleshootingPage", "Make top-level widgets use pure raster surfaces, and do not support non-native GL-based child widgets.", nullptr));
#endif // QT_CONFIG(tooltip)
        forceRasterCheckBox->setText(QCoreApplication::translate("TroubleshootingPage", "Force raster surface", nullptr));
        (void)TroubleshootingPage;
    } // retranslateUi

};

namespace Ui {
    class TroubleshootingPage: public Ui_TroubleshootingPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_TROUBLESHOOTINGPAGE_H
