/********************************************************************************
** Form generated from reading UI file 'previewform.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREVIEWFORM_H
#define UI_PREVIEWFORM_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_PreviewForm
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget;
    QWidget *tab_3;
    QGridLayout *gridLayout_4;
    QPushButton *pushButton_3;
    QProgressBar *progressBar_2;
    QLineEdit *lineEdit_2;
    QSpinBox *spinBox_2;
    QWidget *tab_4;
    QVBoxLayout *verticalLayout_3;
    QRadioButton *radioButton_7;
    QCheckBox *checkBox_2;

    void setupUi(QWidget *PreviewForm)
    {
        if (PreviewForm->objectName().isEmpty())
            PreviewForm->setObjectName("PreviewForm");
        PreviewForm->resize(281, 130);
        verticalLayout = new QVBoxLayout(PreviewForm);
        verticalLayout->setObjectName("verticalLayout");
        tabWidget = new QTabWidget(PreviewForm);
        tabWidget->setObjectName("tabWidget");
        tabWidget->setFocusPolicy(Qt::NoFocus);
        tab_3 = new QWidget();
        tab_3->setObjectName("tab_3");
        gridLayout_4 = new QGridLayout(tab_3);
        gridLayout_4->setObjectName("gridLayout_4");
        pushButton_3 = new QPushButton(tab_3);
        pushButton_3->setObjectName("pushButton_3");
        pushButton_3->setFocusPolicy(Qt::NoFocus);

        gridLayout_4->addWidget(pushButton_3, 1, 0, 1, 1);

        progressBar_2 = new QProgressBar(tab_3);
        progressBar_2->setObjectName("progressBar_2");
        progressBar_2->setValue(24);

        gridLayout_4->addWidget(progressBar_2, 1, 1, 1, 2);

        lineEdit_2 = new QLineEdit(tab_3);
        lineEdit_2->setObjectName("lineEdit_2");
        lineEdit_2->setFocusPolicy(Qt::NoFocus);

        gridLayout_4->addWidget(lineEdit_2, 0, 0, 1, 1);

        spinBox_2 = new QSpinBox(tab_3);
        spinBox_2->setObjectName("spinBox_2");
        spinBox_2->setFocusPolicy(Qt::NoFocus);

        gridLayout_4->addWidget(spinBox_2, 0, 1, 1, 2);

        tabWidget->addTab(tab_3, QString());
        tab_4 = new QWidget();
        tab_4->setObjectName("tab_4");
        verticalLayout_3 = new QVBoxLayout(tab_4);
        verticalLayout_3->setObjectName("verticalLayout_3");
        radioButton_7 = new QRadioButton(tab_4);
        radioButton_7->setObjectName("radioButton_7");
        radioButton_7->setFocusPolicy(Qt::NoFocus);

        verticalLayout_3->addWidget(radioButton_7);

        checkBox_2 = new QCheckBox(tab_4);
        checkBox_2->setObjectName("checkBox_2");
        checkBox_2->setFocusPolicy(Qt::NoFocus);

        verticalLayout_3->addWidget(checkBox_2);

        tabWidget->addTab(tab_4, QString());

        verticalLayout->addWidget(tabWidget);


        retranslateUi(PreviewForm);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(PreviewForm);
    } // setupUi

    void retranslateUi(QWidget *PreviewForm)
    {
        PreviewForm->setWindowTitle(QCoreApplication::translate("PreviewForm", "Preview Window", nullptr));
        pushButton_3->setText(QCoreApplication::translate("PreviewForm", "PushButton", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_3), QCoreApplication::translate("PreviewForm", "Tab 1", nullptr));
        radioButton_7->setText(QCoreApplication::translate("PreviewForm", "RadioButton", nullptr));
        checkBox_2->setText(QCoreApplication::translate("PreviewForm", "CheckBox", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_4), QCoreApplication::translate("PreviewForm", "Tab 2", nullptr));
    } // retranslateUi

};

namespace Ui {
    class PreviewForm: public Ui_PreviewForm {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PREVIEWFORM_H
