/********************************************************************************
** Form generated from reading UI file 'paletteeditdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PALETTEEDITDIALOG_H
#define UI_PALETTEEDITDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTableWidget>

QT_BEGIN_NAMESPACE

class Ui_PaletteEditDialog
{
public:
    QGridLayout *gridLayout;
    QPushButton *buildInactiveButton;
    QPushButton *buildDisabledButton;
    QSpacerItem *horizontalSpacer;
    QDialogButtonBox *buttonBox;
    QTableWidget *tableWidget;
    QPushButton *resetPaletteButton;

    void setupUi(QDialog *PaletteEditDialog)
    {
        if (PaletteEditDialog->objectName().isEmpty())
            PaletteEditDialog->setObjectName("PaletteEditDialog");
        PaletteEditDialog->resize(631, 529);
        gridLayout = new QGridLayout(PaletteEditDialog);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(6, -1, 6, 6);
        buildInactiveButton = new QPushButton(PaletteEditDialog);
        buildInactiveButton->setObjectName("buildInactiveButton");

        gridLayout->addWidget(buildInactiveButton, 3, 0, 1, 1);

        buildDisabledButton = new QPushButton(PaletteEditDialog);
        buildDisabledButton->setObjectName("buildDisabledButton");

        gridLayout->addWidget(buildDisabledButton, 3, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(117, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 3, 3, 1, 1);

        buttonBox = new QDialogButtonBox(PaletteEditDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 9, 0, 1, 5);

        tableWidget = new QTableWidget(PaletteEditDialog);
        tableWidget->setObjectName("tableWidget");
        tableWidget->setEditTriggers(QAbstractItemView::NoEditTriggers);
        tableWidget->setSelectionMode(QAbstractItemView::NoSelection);
        tableWidget->setColumnCount(0);

        gridLayout->addWidget(tableWidget, 0, 0, 1, 5);

        resetPaletteButton = new QPushButton(PaletteEditDialog);
        resetPaletteButton->setObjectName("resetPaletteButton");

        gridLayout->addWidget(resetPaletteButton, 3, 2, 1, 1);

        QWidget::setTabOrder(tableWidget, buildInactiveButton);
        QWidget::setTabOrder(buildInactiveButton, buildDisabledButton);
        QWidget::setTabOrder(buildDisabledButton, resetPaletteButton);
        QWidget::setTabOrder(resetPaletteButton, buttonBox);

        retranslateUi(PaletteEditDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, PaletteEditDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, PaletteEditDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(PaletteEditDialog);
    } // setupUi

    void retranslateUi(QDialog *PaletteEditDialog)
    {
        PaletteEditDialog->setWindowTitle(QCoreApplication::translate("PaletteEditDialog", "Palette Editor", nullptr));
        buildInactiveButton->setText(QCoreApplication::translate("PaletteEditDialog", "Build inactive palette", nullptr));
        buildDisabledButton->setText(QCoreApplication::translate("PaletteEditDialog", "Build disabled palette", nullptr));
        resetPaletteButton->setText(QCoreApplication::translate("PaletteEditDialog", "Reset palette", nullptr));
    } // retranslateUi

};

namespace Ui {
    class PaletteEditDialog: public Ui_PaletteEditDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PALETTEEDITDIALOG_H
