/********************************************************************************
** Form generated from reading UI file 'fontspage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FONTSPAGE_H
#define UI_FONTSPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_FontsPage
{
public:
    QGridLayout *gridLayout_2;
    QSpacerItem *horizontalSpacer;
    QGridLayout *gridLayout;
    QLabel *generalFontLabel;
    QLabel *label_2;
    QToolButton *changeGeneralFontButton;
    QLabel *fixedFontLabel;
    QToolButton *changeFixedWidthFontButton;
    QLabel *label_5;
    QSpacerItem *verticalSpacer;
    QPushButton *createFontsConfButton;
    QPushButton *removeFontsConfButton;

    void setupUi(QWidget *FontsPage)
    {
        if (FontsPage->objectName().isEmpty())
            FontsPage->setObjectName("FontsPage");
        FontsPage->resize(517, 320);
        FontsPage->setWindowTitle(QString::fromUtf8("Form"));
        gridLayout_2 = new QGridLayout(FontsPage);
        gridLayout_2->setObjectName("gridLayout_2");
        horizontalSpacer = new QSpacerItem(342, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer, 1, 2, 1, 1);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        generalFontLabel = new QLabel(FontsPage);
        generalFontLabel->setObjectName("generalFontLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(generalFontLabel->sizePolicy().hasHeightForWidth());
        generalFontLabel->setSizePolicy(sizePolicy);
        generalFontLabel->setFrameShape(QFrame::StyledPanel);
        generalFontLabel->setFrameShadow(QFrame::Sunken);

        gridLayout->addWidget(generalFontLabel, 0, 1, 1, 1);

        label_2 = new QLabel(FontsPage);
        label_2->setObjectName("label_2");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(label_2->sizePolicy().hasHeightForWidth());
        label_2->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(label_2, 0, 0, 1, 1);

        changeGeneralFontButton = new QToolButton(FontsPage);
        changeGeneralFontButton->setObjectName("changeGeneralFontButton");

        gridLayout->addWidget(changeGeneralFontButton, 0, 2, 1, 1);

        fixedFontLabel = new QLabel(FontsPage);
        fixedFontLabel->setObjectName("fixedFontLabel");
        sizePolicy1.setHeightForWidth(fixedFontLabel->sizePolicy().hasHeightForWidth());
        fixedFontLabel->setSizePolicy(sizePolicy1);
        fixedFontLabel->setFrameShape(QFrame::StyledPanel);
        fixedFontLabel->setFrameShadow(QFrame::Sunken);

        gridLayout->addWidget(fixedFontLabel, 1, 1, 1, 1);

        changeFixedWidthFontButton = new QToolButton(FontsPage);
        changeFixedWidthFontButton->setObjectName("changeFixedWidthFontButton");

        gridLayout->addWidget(changeFixedWidthFontButton, 1, 2, 1, 1);

        label_5 = new QLabel(FontsPage);
        label_5->setObjectName("label_5");

        gridLayout->addWidget(label_5, 1, 0, 1, 1);


        gridLayout_2->addLayout(gridLayout, 0, 0, 1, 3);

        verticalSpacer = new QSpacerItem(0, 280, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 2, 0, 1, 3);

        createFontsConfButton = new QPushButton(FontsPage);
        createFontsConfButton->setObjectName("createFontsConfButton");

        gridLayout_2->addWidget(createFontsConfButton, 1, 0, 1, 1);

        removeFontsConfButton = new QPushButton(FontsPage);
        removeFontsConfButton->setObjectName("removeFontsConfButton");

        gridLayout_2->addWidget(removeFontsConfButton, 1, 1, 1, 1);

        QWidget::setTabOrder(changeGeneralFontButton, changeFixedWidthFontButton);
        QWidget::setTabOrder(changeFixedWidthFontButton, createFontsConfButton);
        QWidget::setTabOrder(createFontsConfButton, removeFontsConfButton);

        retranslateUi(FontsPage);

        QMetaObject::connectSlotsByName(FontsPage);
    } // setupUi

    void retranslateUi(QWidget *FontsPage)
    {
        generalFontLabel->setText(QCoreApplication::translate("FontsPage", "...", nullptr));
        label_2->setText(QCoreApplication::translate("FontsPage", "General:", nullptr));
        changeGeneralFontButton->setText(QCoreApplication::translate("FontsPage", "...", nullptr));
        fixedFontLabel->setText(QCoreApplication::translate("FontsPage", "...", nullptr));
        changeFixedWidthFontButton->setText(QCoreApplication::translate("FontsPage", "...", nullptr));
        label_5->setText(QCoreApplication::translate("FontsPage", "Fixed width:", nullptr));
        createFontsConfButton->setText(QCoreApplication::translate("FontsPage", "Create  fonts.conf", nullptr));
        removeFontsConfButton->setText(QCoreApplication::translate("FontsPage", "Remove fonts.conf", nullptr));
        (void)FontsPage;
    } // retranslateUi

};

namespace Ui {
    class FontsPage: public Ui_FontsPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_FONTSPAGE_H
