/********************************************************************************
** Form generated from reading UI file 'interfacepage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_INTERFACEPAGE_H
#define UI_INTERFACEPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_InterfacePage
{
public:
    QGridLayout *gridLayout;
    QSpacerItem *verticalSpacer;
    QFormLayout *formLayout;
    QLabel *label;
    QLabel *label_2;
    QLabel *label_3;
    QLabel *label_4;
    QLabel *label_5;
    QSpinBox *doubleClickIntervalSpinBox;
    QSpinBox *cursorFlashTimeSpinBox;
    QComboBox *comboBoxEffectComboBox;
    QComboBox *toolTipEffectComboBox;
    QComboBox *toolBoxEffectComboBox;
    QLabel *label_6;
    QComboBox *menuEffectComboBox;
    QCheckBox *guiEffectsCheckBox;
    QLabel *label_7;
    QComboBox *buttonLayoutComboBox;
    QLabel *label_10;
    QComboBox *keyboardSchemeComboBox;
    QCheckBox *menuIconsCheckBox;
    QCheckBox *dialogIconsCheckBox;
    QCheckBox *singleClickCheckBox;
    QLabel *label_8;
    QComboBox *toolButtonStyleComboBox;
    QLabel *label_9;
    QSpinBox *wheelScrollLinesSpinBox;
    QCheckBox *shortcutUnderlineCheckBox;
    QCheckBox *showShortcutsInMenusCheckBox;
    QSpacerItem *horizontalSpacer;

    void setupUi(QWidget *InterfacePage)
    {
        if (InterfacePage->objectName().isEmpty())
            InterfacePage->setObjectName("InterfacePage");
        InterfacePage->resize(500, 546);
        InterfacePage->setWindowTitle(QString::fromUtf8("Form"));
        gridLayout = new QGridLayout(InterfacePage);
        gridLayout->setObjectName("gridLayout");
        verticalSpacer = new QSpacerItem(20, 259, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 2, 0, 1, 1);

        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        label = new QLabel(InterfacePage);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        label_2 = new QLabel(InterfacePage);
        label_2->setObjectName("label_2");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        label_3 = new QLabel(InterfacePage);
        label_3->setObjectName("label_3");

        formLayout->setWidget(5, QFormLayout::ItemRole::LabelRole, label_3);

        label_4 = new QLabel(InterfacePage);
        label_4->setObjectName("label_4");

        formLayout->setWidget(6, QFormLayout::ItemRole::LabelRole, label_4);

        label_5 = new QLabel(InterfacePage);
        label_5->setObjectName("label_5");

        formLayout->setWidget(7, QFormLayout::ItemRole::LabelRole, label_5);

        doubleClickIntervalSpinBox = new QSpinBox(InterfacePage);
        doubleClickIntervalSpinBox->setObjectName("doubleClickIntervalSpinBox");
        doubleClickIntervalSpinBox->setMaximum(2000);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, doubleClickIntervalSpinBox);

        cursorFlashTimeSpinBox = new QSpinBox(InterfacePage);
        cursorFlashTimeSpinBox->setObjectName("cursorFlashTimeSpinBox");
        cursorFlashTimeSpinBox->setMaximum(4000);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, cursorFlashTimeSpinBox);

        comboBoxEffectComboBox = new QComboBox(InterfacePage);
        comboBoxEffectComboBox->addItem(QString());
        comboBoxEffectComboBox->addItem(QString());
        comboBoxEffectComboBox->setObjectName("comboBoxEffectComboBox");
        comboBoxEffectComboBox->setEnabled(false);

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, comboBoxEffectComboBox);

        toolTipEffectComboBox = new QComboBox(InterfacePage);
        toolTipEffectComboBox->addItem(QString());
        toolTipEffectComboBox->addItem(QString());
        toolTipEffectComboBox->addItem(QString());
        toolTipEffectComboBox->setObjectName("toolTipEffectComboBox");
        toolTipEffectComboBox->setEnabled(false);

        formLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, toolTipEffectComboBox);

        toolBoxEffectComboBox = new QComboBox(InterfacePage);
        toolBoxEffectComboBox->addItem(QString());
        toolBoxEffectComboBox->addItem(QString());
        toolBoxEffectComboBox->setObjectName("toolBoxEffectComboBox");
        toolBoxEffectComboBox->setEnabled(false);

        formLayout->setWidget(7, QFormLayout::ItemRole::FieldRole, toolBoxEffectComboBox);

        label_6 = new QLabel(InterfacePage);
        label_6->setObjectName("label_6");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, label_6);

        menuEffectComboBox = new QComboBox(InterfacePage);
        menuEffectComboBox->addItem(QString());
        menuEffectComboBox->addItem(QString());
        menuEffectComboBox->addItem(QString());
        menuEffectComboBox->setObjectName("menuEffectComboBox");
        menuEffectComboBox->setEnabled(false);

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, menuEffectComboBox);

        guiEffectsCheckBox = new QCheckBox(InterfacePage);
        guiEffectsCheckBox->setObjectName("guiEffectsCheckBox");

        formLayout->setWidget(3, QFormLayout::ItemRole::SpanningRole, guiEffectsCheckBox);

        label_7 = new QLabel(InterfacePage);
        label_7->setObjectName("label_7");

        formLayout->setWidget(8, QFormLayout::ItemRole::LabelRole, label_7);

        buttonLayoutComboBox = new QComboBox(InterfacePage);
        buttonLayoutComboBox->setObjectName("buttonLayoutComboBox");

        formLayout->setWidget(8, QFormLayout::ItemRole::FieldRole, buttonLayoutComboBox);

        label_10 = new QLabel(InterfacePage);
        label_10->setObjectName("label_10");

        formLayout->setWidget(9, QFormLayout::ItemRole::LabelRole, label_10);

        keyboardSchemeComboBox = new QComboBox(InterfacePage);
        keyboardSchemeComboBox->setObjectName("keyboardSchemeComboBox");

        formLayout->setWidget(9, QFormLayout::ItemRole::FieldRole, keyboardSchemeComboBox);

        menuIconsCheckBox = new QCheckBox(InterfacePage);
        menuIconsCheckBox->setObjectName("menuIconsCheckBox");

        formLayout->setWidget(11, QFormLayout::ItemRole::SpanningRole, menuIconsCheckBox);

        dialogIconsCheckBox = new QCheckBox(InterfacePage);
        dialogIconsCheckBox->setObjectName("dialogIconsCheckBox");
        dialogIconsCheckBox->setTristate(true);

        formLayout->setWidget(10, QFormLayout::ItemRole::SpanningRole, dialogIconsCheckBox);

        singleClickCheckBox = new QCheckBox(InterfacePage);
        singleClickCheckBox->setObjectName("singleClickCheckBox");
        singleClickCheckBox->setTristate(true);

        formLayout->setWidget(2, QFormLayout::ItemRole::SpanningRole, singleClickCheckBox);

        label_8 = new QLabel(InterfacePage);
        label_8->setObjectName("label_8");

        formLayout->setWidget(14, QFormLayout::ItemRole::LabelRole, label_8);

        toolButtonStyleComboBox = new QComboBox(InterfacePage);
        toolButtonStyleComboBox->setObjectName("toolButtonStyleComboBox");

        formLayout->setWidget(14, QFormLayout::ItemRole::FieldRole, toolButtonStyleComboBox);

        label_9 = new QLabel(InterfacePage);
        label_9->setObjectName("label_9");

        formLayout->setWidget(15, QFormLayout::ItemRole::LabelRole, label_9);

        wheelScrollLinesSpinBox = new QSpinBox(InterfacePage);
        wheelScrollLinesSpinBox->setObjectName("wheelScrollLinesSpinBox");
        wheelScrollLinesSpinBox->setMinimum(1);
        wheelScrollLinesSpinBox->setMaximum(20);

        formLayout->setWidget(15, QFormLayout::ItemRole::FieldRole, wheelScrollLinesSpinBox);

        shortcutUnderlineCheckBox = new QCheckBox(InterfacePage);
        shortcutUnderlineCheckBox->setObjectName("shortcutUnderlineCheckBox");
        shortcutUnderlineCheckBox->setTristate(true);

        formLayout->setWidget(13, QFormLayout::ItemRole::SpanningRole, shortcutUnderlineCheckBox);

        showShortcutsInMenusCheckBox = new QCheckBox(InterfacePage);
        showShortcutsInMenusCheckBox->setObjectName("showShortcutsInMenusCheckBox");

        formLayout->setWidget(12, QFormLayout::ItemRole::SpanningRole, showShortcutsInMenusCheckBox);


        gridLayout->addLayout(formLayout, 0, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(238, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 1, 1, 1);

        QWidget::setTabOrder(doubleClickIntervalSpinBox, cursorFlashTimeSpinBox);
        QWidget::setTabOrder(cursorFlashTimeSpinBox, singleClickCheckBox);
        QWidget::setTabOrder(singleClickCheckBox, guiEffectsCheckBox);
        QWidget::setTabOrder(guiEffectsCheckBox, menuEffectComboBox);
        QWidget::setTabOrder(menuEffectComboBox, comboBoxEffectComboBox);
        QWidget::setTabOrder(comboBoxEffectComboBox, toolTipEffectComboBox);
        QWidget::setTabOrder(toolTipEffectComboBox, toolBoxEffectComboBox);
        QWidget::setTabOrder(toolBoxEffectComboBox, buttonLayoutComboBox);
        QWidget::setTabOrder(buttonLayoutComboBox, dialogIconsCheckBox);
        QWidget::setTabOrder(dialogIconsCheckBox, menuIconsCheckBox);
        QWidget::setTabOrder(menuIconsCheckBox, shortcutUnderlineCheckBox);
        QWidget::setTabOrder(shortcutUnderlineCheckBox, toolButtonStyleComboBox);
        QWidget::setTabOrder(toolButtonStyleComboBox, wheelScrollLinesSpinBox);

        retranslateUi(InterfacePage);
        QObject::connect(guiEffectsCheckBox, &QCheckBox::toggled, menuEffectComboBox, &QComboBox::setEnabled);
        QObject::connect(guiEffectsCheckBox, &QCheckBox::toggled, comboBoxEffectComboBox, &QComboBox::setEnabled);
        QObject::connect(guiEffectsCheckBox, &QCheckBox::toggled, toolTipEffectComboBox, &QComboBox::setEnabled);
        QObject::connect(guiEffectsCheckBox, &QCheckBox::toggled, toolBoxEffectComboBox, &QComboBox::setEnabled);

        QMetaObject::connectSlotsByName(InterfacePage);
    } // setupUi

    void retranslateUi(QWidget *InterfacePage)
    {
        label->setText(QCoreApplication::translate("InterfacePage", "Double click interval:", nullptr));
        label_2->setText(QCoreApplication::translate("InterfacePage", "Cursor flash time:", nullptr));
        label_3->setText(QCoreApplication::translate("InterfacePage", "ComboBox effect:", nullptr));
        label_4->setText(QCoreApplication::translate("InterfacePage", "ToolTip effect:", nullptr));
        label_5->setText(QCoreApplication::translate("InterfacePage", "ToolBox effect:", nullptr));
        doubleClickIntervalSpinBox->setSuffix(QCoreApplication::translate("InterfacePage", " ms", nullptr));
        cursorFlashTimeSpinBox->setSuffix(QCoreApplication::translate("InterfacePage", " ms", nullptr));
        comboBoxEffectComboBox->setItemText(0, QCoreApplication::translate("InterfacePage", "Disable", nullptr));
        comboBoxEffectComboBox->setItemText(1, QCoreApplication::translate("InterfacePage", "Animate", nullptr));

        toolTipEffectComboBox->setItemText(0, QCoreApplication::translate("InterfacePage", "Disable", nullptr));
        toolTipEffectComboBox->setItemText(1, QCoreApplication::translate("InterfacePage", "Animate", nullptr));
        toolTipEffectComboBox->setItemText(2, QCoreApplication::translate("InterfacePage", "Fade", nullptr));

        toolBoxEffectComboBox->setItemText(0, QCoreApplication::translate("InterfacePage", "Disable", nullptr));
        toolBoxEffectComboBox->setItemText(1, QCoreApplication::translate("InterfacePage", "Animate", nullptr));

        label_6->setText(QCoreApplication::translate("InterfacePage", "Menu effect:", nullptr));
        menuEffectComboBox->setItemText(0, QCoreApplication::translate("InterfacePage", "Disable", nullptr));
        menuEffectComboBox->setItemText(1, QCoreApplication::translate("InterfacePage", "Animate", nullptr));
        menuEffectComboBox->setItemText(2, QCoreApplication::translate("InterfacePage", "Fade", nullptr));

        guiEffectsCheckBox->setText(QCoreApplication::translate("InterfacePage", "Enable gui effects", nullptr));
        label_7->setText(QCoreApplication::translate("InterfacePage", "Dialog buttons layout:", nullptr));
        label_10->setText(QCoreApplication::translate("InterfacePage", "Keyboard scheme:", nullptr));
        menuIconsCheckBox->setText(QCoreApplication::translate("InterfacePage", "Menus have icons", nullptr));
        dialogIconsCheckBox->setText(QCoreApplication::translate("InterfacePage", "Dialog buttons have icons", nullptr));
        singleClickCheckBox->setText(QCoreApplication::translate("InterfacePage", "Activate item on single-click", nullptr));
        label_8->setText(QCoreApplication::translate("InterfacePage", "Toolbar button style:", nullptr));
        label_9->setText(QCoreApplication::translate("InterfacePage", "Mouse wheel scroll lines:", nullptr));
        shortcutUnderlineCheckBox->setText(QCoreApplication::translate("InterfacePage", "Show shortcut underlines", nullptr));
        showShortcutsInMenusCheckBox->setText(QCoreApplication::translate("InterfacePage", "Show shortcuts in context menus", nullptr));
        (void)InterfacePage;
    } // retranslateUi

};

namespace Ui {
    class InterfacePage: public Ui_InterfacePage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_INTERFACEPAGE_H
