/********************************************************************************
** Form generated from reading UI file 'iconthemepage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ICONTHEMEPAGE_H
#define UI_ICONTHEMEPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_IconThemePage
{
public:
    QVBoxLayout *verticalLayout;
    QTreeWidget *treeWidget;

    void setupUi(QWidget *IconThemePage)
    {
        if (IconThemePage->objectName().isEmpty())
            IconThemePage->setObjectName("IconThemePage");
        IconThemePage->resize(400, 300);
        IconThemePage->setWindowTitle(QString::fromUtf8("Form"));
        verticalLayout = new QVBoxLayout(IconThemePage);
        verticalLayout->setObjectName("verticalLayout");
        treeWidget = new QTreeWidget(IconThemePage);
        QTreeWidgetItem *__qtreewidgetitem = new QTreeWidgetItem();
        __qtreewidgetitem->setText(3, QString::fromUtf8("4"));
        __qtreewidgetitem->setText(2, QString::fromUtf8("3"));
        __qtreewidgetitem->setText(1, QString::fromUtf8("2"));
        __qtreewidgetitem->setText(0, QString::fromUtf8("1"));
        treeWidget->setHeaderItem(__qtreewidgetitem);
        treeWidget->setObjectName("treeWidget");
        treeWidget->setColumnCount(4);
        treeWidget->header()->setVisible(false);

        verticalLayout->addWidget(treeWidget);


        retranslateUi(IconThemePage);

        QMetaObject::connectSlotsByName(IconThemePage);
    } // setupUi

    void retranslateUi(QWidget *IconThemePage)
    {
        (void)IconThemePage;
    } // retranslateUi

};

namespace Ui {
    class IconThemePage: public Ui_IconThemePage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ICONTHEMEPAGE_H
